# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x11org.couchers.auth\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\"\xfb\x02\n\rSignupFlowReq\x12\x18\n\nflow_token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\x12-\n\x05\x62\x61sic\x18\x02 \x01(\x0b\x32\x1e.org.couchers.auth.SignupBasic\x12\x31\n\x07\x61\x63\x63ount\x18\x03 \x01(\x0b\x32 .org.couchers.auth.SignupAccount\x12\x34\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x04 \x01(\x0b\x32\".org.couchers.auth.ContributorForm\x12\x39\n\x0bmotivations\x18\x08 \x01(\x0b\x32$.org.couchers.auth.SignupMotivations\x12\x19\n\x0b\x65mail_token\x18\x05 \x01(\tB\x04\x88\xb5\x18\x01\x12?\n\x1b\x61\x63\x63\x65pt_community_guidelines\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12!\n\x19resend_verification_email\x18\x07 \x01(\x08\"\xf7\x01\n\rSignupFlowRes\x12\x18\n\nflow_token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\x12,\n\x08\x61uth_res\x18\x03 \x01(\x0b\x32\x1a.org.couchers.auth.AuthRes\x12\x12\n\nneed_basic\x18\x04 \x01(\x08\x12\x14\n\x0cneed_account\x18\x05 \x01(\x08\x12\x15\n\rneed_feedback\x18\x06 \x01(\x08\x12\x18\n\x10need_motivations\x18\t \x01(\x08\x12\x19\n\x11need_verify_email\x18\x07 \x01(\x08\x12(\n need_accept_community_guidelines\x18\x08 \x01(\x08\"?\n\x0bSignupBasic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x13\n\x0binvite_code\x18\x03 \x01(\t\"0\n\x12SignupTokenInfoReq\x12\x1a\n\x0csignup_token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\"\x85\x02\n\rSignupAccount\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x16\n\x08password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12\x0c\n\x04\x63ity\x18\x06 \x01(\t\x12\x0b\n\x03lat\x18\x07 \x01(\x01\x12\x0b\n\x03lng\x18\x08 \x01(\x01\x12\x0e\n\x06radius\x18\t \x01(\x01\x12\x11\n\tbirthdate\x18\x03 \x01(\t\x12\x0e\n\x06gender\x18\x04 \x01(\t\x12<\n\x0ehosting_status\x18\x05 \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12\x12\n\naccept_tos\x18\n \x01(\x08\x12\x1d\n\x15opt_out_of_newsletter\x18\x0b \x01(\x08\"F\n\x11SignupMotivations\x12\x1c\n\x14heard_about_couchers\x18\x01 \x01(\t\x12\x13\n\x0bmotivations\x18\x02 \x03(\t\"$\n\x10UsernameValidReq\x12\x10\n\x08username\x18\x01 \x01(\t\"!\n\x10UsernameValidRes\x12\r\n\x05valid\x18\x01 \x01(\x08\"H\n\x07\x41uthReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x16\n\x08password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12\x17\n\x0fremember_device\x18\x03 \x01(\x08\"*\n\x07\x41uthRes\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x0e\n\x06jailed\x18\x02 \x01(\x08\"R\n\x0fGetAuthStateRes\x12\x11\n\tlogged_in\x18\x01 \x01(\x08\x12,\n\x08\x61uth_res\x18\x02 \x01(\x0b\x32\x1a.org.couchers.auth.AuthRes\" \n\x10ResetPasswordReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\\\n\x1a\x43ompletePasswordResetV2Req\x12\"\n\x14password_reset_token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\x12\x1a\n\x0cnew_password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\";\n\x17\x43onfirmChangeEmailV2Req\x12 \n\x12\x63hange_email_token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\"\xab\x01\n\x0f\x43ontributorForm\x12\r\n\x05ideas\x18\x01 \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x02 \x01(\t\x12\x12\n\nexperience\x18\x03 \x01(\t\x12\x37\n\ncontribute\x18\x04 \x01(\x0e\x32#.org.couchers.auth.ContributeOption\x12\x17\n\x0f\x63ontribute_ways\x18\x05 \x03(\t\x12\x11\n\texpertise\x18\x06 \x01(\t\".\n\x17\x43onfirmDeleteAccountReq\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\"(\n\x11RecoverAccountReq\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\".\n\x0eUnsubscribeReq\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x0b\n\x03sig\x18\x02 \x01(\x0c\"\"\n\x0eUnsubscribeRes\x12\x10\n\x08response\x18\x01 \x01(\t\"+\n\nAntiBotReq\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\"\x0c\n\nAntiBotRes\"\x12\n\x10\x41ntiBotPolicyReq\"*\n\x10\x41ntiBotPolicyRes\x12\x16\n\x0eshould_antibot\x18\x01 \x01(\x08\"$\n\x14GetInviteCodeInfoReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"W\n\x14GetInviteCodeInfoRes\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x12\n\navatar_url\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t*\x87\x01\n\x10\x43ontributeOption\x12!\n\x1d\x43ONTRIBUTE_OPTION_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43ONTRIBUTE_OPTION_YES\x10\x01\x12\x1b\n\x17\x43ONTRIBUTE_OPTION_MAYBE\x10\x02\x12\x18\n\x14\x43ONTRIBUTE_OPTION_NO\x10\x03\x32\xc7\t\n\x04\x41uth\x12R\n\nSignupFlow\x12 .org.couchers.auth.SignupFlowReq\x1a .org.couchers.auth.SignupFlowRes\"\x00\x12[\n\rUsernameValid\x12#.org.couchers.auth.UsernameValidReq\x1a#.org.couchers.auth.UsernameValidRes\"\x00\x12H\n\x0c\x41uthenticate\x12\x1a.org.couchers.auth.AuthReq\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12L\n\x0cGetAuthState\x12\x16.google.protobuf.Empty\x1a\".org.couchers.auth.GetAuthStateRes\"\x00\x12\x42\n\x0e\x44\x65\x61uthenticate\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\rResetPassword\x12#.org.couchers.auth.ResetPasswordReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x66\n\x17\x43ompletePasswordResetV2\x12-.org.couchers.auth.CompletePasswordResetV2Req\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12\\\n\x14\x43onfirmChangeEmailV2\x12*.org.couchers.auth.ConfirmChangeEmailV2Req\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x14\x43onfirmDeleteAccount\x12*.org.couchers.auth.ConfirmDeleteAccountReq\x1a\x16.google.protobuf.Empty\"\x00\x12P\n\x0eRecoverAccount\x12$.org.couchers.auth.RecoverAccountReq\x1a\x16.google.protobuf.Empty\"\x00\x12U\n\x0bUnsubscribe\x12!.org.couchers.auth.UnsubscribeReq\x1a!.org.couchers.auth.UnsubscribeRes\"\x00\x12I\n\x07\x41ntiBot\x12\x1d.org.couchers.auth.AntiBotReq\x1a\x1d.org.couchers.auth.AntiBotRes\"\x00\x12[\n\rAntiBotPolicy\x12#.org.couchers.auth.AntiBotPolicyReq\x1a#.org.couchers.auth.AntiBotPolicyRes\"\x00\x12g\n\x11GetInviteCodeInfo\x12\'.org.couchers.auth.GetInviteCodeInfoReq\x1a\'.org.couchers.auth.GetInviteCodeInfoRes\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SIGNUPFLOWREQ'].fields_by_name['flow_token']._loaded_options = None
  _globals['_SIGNUPFLOWREQ'].fields_by_name['flow_token']._serialized_options = b'\210\265\030\001'
  _globals['_SIGNUPFLOWREQ'].fields_by_name['email_token']._loaded_options = None
  _globals['_SIGNUPFLOWREQ'].fields_by_name['email_token']._serialized_options = b'\210\265\030\001'
  _globals['_SIGNUPFLOWRES'].fields_by_name['flow_token']._loaded_options = None
  _globals['_SIGNUPFLOWRES'].fields_by_name['flow_token']._serialized_options = b'\210\265\030\001'
  _globals['_SIGNUPTOKENINFOREQ'].fields_by_name['signup_token']._loaded_options = None
  _globals['_SIGNUPTOKENINFOREQ'].fields_by_name['signup_token']._serialized_options = b'\210\265\030\001'
  _globals['_SIGNUPACCOUNT'].fields_by_name['password']._loaded_options = None
  _globals['_SIGNUPACCOUNT'].fields_by_name['password']._serialized_options = b'\200\265\030\001'
  _globals['_AUTHREQ'].fields_by_name['password']._loaded_options = None
  _globals['_AUTHREQ'].fields_by_name['password']._serialized_options = b'\200\265\030\001'
  _globals['_COMPLETEPASSWORDRESETV2REQ'].fields_by_name['password_reset_token']._loaded_options = None
  _globals['_COMPLETEPASSWORDRESETV2REQ'].fields_by_name['password_reset_token']._serialized_options = b'\210\265\030\001'
  _globals['_COMPLETEPASSWORDRESETV2REQ'].fields_by_name['new_password']._loaded_options = None
  _globals['_COMPLETEPASSWORDRESETV2REQ'].fields_by_name['new_password']._serialized_options = b'\200\265\030\001'
  _globals['_CONFIRMCHANGEEMAILV2REQ'].fields_by_name['change_email_token']._loaded_options = None
  _globals['_CONFIRMCHANGEEMAILV2REQ'].fields_by_name['change_email_token']._serialized_options = b'\210\265\030\001'
  _globals['_CONFIRMDELETEACCOUNTREQ'].fields_by_name['token']._loaded_options = None
  _globals['_CONFIRMDELETEACCOUNTREQ'].fields_by_name['token']._serialized_options = b'\210\265\030\001'
  _globals['_RECOVERACCOUNTREQ'].fields_by_name['token']._loaded_options = None
  _globals['_RECOVERACCOUNTREQ'].fields_by_name['token']._serialized_options = b'\210\265\030\001'
  _globals['_AUTH']._loaded_options = None
  _globals['_AUTH']._serialized_options = b'\210\265\030\001'
  _globals['_CONTRIBUTEOPTION']._serialized_start=2270
  _globals['_CONTRIBUTEOPTION']._serialized_end=2405
  _globals['_SIGNUPFLOWREQ']._serialized_start=125
  _globals['_SIGNUPFLOWREQ']._serialized_end=504
  _globals['_SIGNUPFLOWRES']._serialized_start=507
  _globals['_SIGNUPFLOWRES']._serialized_end=754
  _globals['_SIGNUPBASIC']._serialized_start=756
  _globals['_SIGNUPBASIC']._serialized_end=819
  _globals['_SIGNUPTOKENINFOREQ']._serialized_start=821
  _globals['_SIGNUPTOKENINFOREQ']._serialized_end=869
  _globals['_SIGNUPACCOUNT']._serialized_start=872
  _globals['_SIGNUPACCOUNT']._serialized_end=1133
  _globals['_SIGNUPMOTIVATIONS']._serialized_start=1135
  _globals['_SIGNUPMOTIVATIONS']._serialized_end=1205
  _globals['_USERNAMEVALIDREQ']._serialized_start=1207
  _globals['_USERNAMEVALIDREQ']._serialized_end=1243
  _globals['_USERNAMEVALIDRES']._serialized_start=1245
  _globals['_USERNAMEVALIDRES']._serialized_end=1278
  _globals['_AUTHREQ']._serialized_start=1280
  _globals['_AUTHREQ']._serialized_end=1352
  _globals['_AUTHRES']._serialized_start=1354
  _globals['_AUTHRES']._serialized_end=1396
  _globals['_GETAUTHSTATERES']._serialized_start=1398
  _globals['_GETAUTHSTATERES']._serialized_end=1480
  _globals['_RESETPASSWORDREQ']._serialized_start=1482
  _globals['_RESETPASSWORDREQ']._serialized_end=1514
  _globals['_COMPLETEPASSWORDRESETV2REQ']._serialized_start=1516
  _globals['_COMPLETEPASSWORDRESETV2REQ']._serialized_end=1608
  _globals['_CONFIRMCHANGEEMAILV2REQ']._serialized_start=1610
  _globals['_CONFIRMCHANGEEMAILV2REQ']._serialized_end=1669
  _globals['_CONTRIBUTORFORM']._serialized_start=1672
  _globals['_CONTRIBUTORFORM']._serialized_end=1843
  _globals['_CONFIRMDELETEACCOUNTREQ']._serialized_start=1845
  _globals['_CONFIRMDELETEACCOUNTREQ']._serialized_end=1891
  _globals['_RECOVERACCOUNTREQ']._serialized_start=1893
  _globals['_RECOVERACCOUNTREQ']._serialized_end=1933
  _globals['_UNSUBSCRIBEREQ']._serialized_start=1935
  _globals['_UNSUBSCRIBEREQ']._serialized_end=1981
  _globals['_UNSUBSCRIBERES']._serialized_start=1983
  _globals['_UNSUBSCRIBERES']._serialized_end=2017
  _globals['_ANTIBOTREQ']._serialized_start=2019
  _globals['_ANTIBOTREQ']._serialized_end=2062
  _globals['_ANTIBOTRES']._serialized_start=2064
  _globals['_ANTIBOTRES']._serialized_end=2076
  _globals['_ANTIBOTPOLICYREQ']._serialized_start=2078
  _globals['_ANTIBOTPOLICYREQ']._serialized_end=2096
  _globals['_ANTIBOTPOLICYRES']._serialized_start=2098
  _globals['_ANTIBOTPOLICYRES']._serialized_end=2140
  _globals['_GETINVITECODEINFOREQ']._serialized_start=2142
  _globals['_GETINVITECODEINFOREQ']._serialized_end=2178
  _globals['_GETINVITECODEINFORES']._serialized_start=2180
  _globals['_GETINVITECODEINFORES']._serialized_end=2267
  _globals['_AUTH']._serialized_start=2408
  _globals['_AUTH']._serialized_end=3631
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _NativeUpdateAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NativeUpdateActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NativeUpdateAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NATIVE_UPDATE_ACTION_UNSPECIFIED: _NativeUpdateAction.ValueType  # 0
    NATIVE_UPDATE_ACTION_NONE: _NativeUpdateAction.ValueType  # 1
    """No update needed."""
    NATIVE_UPDATE_ACTION_OTA: _NativeUpdateAction.ValueType  # 2
    """Fetch and reload an OTA bundle; the client can apply this itself."""
    NATIVE_UPDATE_ACTION_STORE: _NativeUpdateAction.ValueType  # 3
    """Update via the App Store / Play Store."""
    NATIVE_UPDATE_ACTION_REINSTALL: _NativeUpdateAction.ValueType  # 4
    """Delete and reinstall the app (worst case)."""

class NativeUpdateAction(_NativeUpdateAction, metaclass=_NativeUpdateActionEnumTypeWrapper): ...

NATIVE_UPDATE_ACTION_UNSPECIFIED: NativeUpdateAction.ValueType  # 0
NATIVE_UPDATE_ACTION_NONE: NativeUpdateAction.ValueType  # 1
"""No update needed."""
NATIVE_UPDATE_ACTION_OTA: NativeUpdateAction.ValueType  # 2
"""Fetch and reload an OTA bundle; the client can apply this itself."""
NATIVE_UPDATE_ACTION_STORE: NativeUpdateAction.ValueType  # 3
"""Update via the App Store / Play Store."""
NATIVE_UPDATE_ACTION_REINSTALL: NativeUpdateAction.ValueType  # 4
"""Delete and reinstall the app (worst case)."""
Global___NativeUpdateAction: typing_extensions.TypeAlias = NativeUpdateAction

class _NativeUpdateCause:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NativeUpdateCauseEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NativeUpdateCause.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NATIVE_UPDATE_CAUSE_UNSPECIFIED: _NativeUpdateCause.ValueType  # 0
    NATIVE_UPDATE_CAUSE_AGE: _NativeUpdateCause.ValueType  # 1
    """Bundle or binary is past its support window. The user is running an old version."""
    NATIVE_UPDATE_CAUSE_BANNED: _NativeUpdateCause.ValueType  # 2
    """The currently-running bundle has been banned (we shipped a buggy version). The framing on the
    device shifts so we take responsibility rather than implying the user is the one out of date.
    """

class NativeUpdateCause(_NativeUpdateCause, metaclass=_NativeUpdateCauseEnumTypeWrapper): ...

NATIVE_UPDATE_CAUSE_UNSPECIFIED: NativeUpdateCause.ValueType  # 0
NATIVE_UPDATE_CAUSE_AGE: NativeUpdateCause.ValueType  # 1
"""Bundle or binary is past its support window. The user is running an old version."""
NATIVE_UPDATE_CAUSE_BANNED: NativeUpdateCause.ValueType  # 2
"""The currently-running bundle has been banned (we shipped a buggy version). The framing on the
device shifts so we take responsibility rather than implying the user is the one out of date.
"""
Global___NativeUpdateCause: typing_extensions.TypeAlias = NativeUpdateCause

@typing.final
class VersionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    def __init__(
        self,
        *,
        version: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["version", b"version"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___VersionInfo: typing_extensions.TypeAlias = VersionInfo

@typing.final
class ScreenResolution(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    width: builtins.int
    height: builtins.int
    def __init__(
        self,
        *,
        width: builtins.int | None = ...,
        height: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["height", b"height", "width", b"width"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ScreenResolution: typing_extensions.TypeAlias = ScreenResolution

@typing.final
class ReportBugReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RESULTS_FIELD_NUMBER: builtins.int
    FRONTEND_VERSION_FIELD_NUMBER: builtins.int
    USER_AGENT_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    SCREEN_RESOLUTION_FIELD_NUMBER: builtins.int
    subject: builtins.str
    description: builtins.str
    results: builtins.str
    frontend_version: builtins.str
    user_agent: builtins.str
    page: builtins.str
    @property
    def screen_resolution(self) -> Global___ScreenResolution: ...
    def __init__(
        self,
        *,
        subject: builtins.str | None = ...,
        description: builtins.str | None = ...,
        results: builtins.str | None = ...,
        frontend_version: builtins.str | None = ...,
        user_agent: builtins.str | None = ...,
        page: builtins.str | None = ...,
        screen_resolution: Global___ScreenResolution | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["screen_resolution", b"screen_resolution"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["description", b"description", "frontend_version", b"frontend_version", "page", b"page", "results", b"results", "screen_resolution", b"screen_resolution", "subject", b"subject", "user_agent", b"user_agent"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ReportBugReq: typing_extensions.TypeAlias = ReportBugReq

@typing.final
class ReportBugRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUG_ID_FIELD_NUMBER: builtins.int
    BUG_URL_FIELD_NUMBER: builtins.int
    bug_id: builtins.str
    bug_url: builtins.str
    def __init__(
        self,
        *,
        bug_id: builtins.str | None = ...,
        bug_url: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["bug_id", b"bug_id", "bug_url", b"bug_url"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ReportBugRes: typing_extensions.TypeAlias = ReportBugRes

@typing.final
class StatusReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NONCE_FIELD_NUMBER: builtins.int
    nonce: builtins.str
    def __init__(
        self,
        *,
        nonce: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["nonce", b"nonce"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___StatusReq: typing_extensions.TypeAlias = StatusReq

@typing.final
class StatusRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NONCE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    COUCHER_COUNT_FIELD_NUMBER: builtins.int
    STABLE_FIELD_NUMBER: builtins.int
    nonce: builtins.str
    version: builtins.str
    coucher_count: builtins.int
    stable: builtins.bool
    def __init__(
        self,
        *,
        nonce: builtins.str | None = ...,
        version: builtins.str | None = ...,
        coucher_count: builtins.int | None = ...,
        stable: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["coucher_count", b"coucher_count", "nonce", b"nonce", "stable", b"stable", "version", b"version"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___StatusRes: typing_extensions.TypeAlias = StatusRes

@typing.final
class GeolocationSearchInfoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_STRING_FIELD_NUMBER: builtins.int
    NOMINATIM_RESULT_JSON_FIELD_NUMBER: builtins.int
    FORMATTED_RESULT_JSON_FIELD_NUMBER: builtins.int
    DURATION_MS_FIELD_NUMBER: builtins.int
    search_string: builtins.str
    nominatim_result_json: builtins.str
    formatted_result_json: builtins.str
    duration_ms: builtins.int
    def __init__(
        self,
        *,
        search_string: builtins.str | None = ...,
        nominatim_result_json: builtins.str | None = ...,
        formatted_result_json: builtins.str | None = ...,
        duration_ms: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["duration_ms", b"duration_ms", "formatted_result_json", b"formatted_result_json", "nominatim_result_json", b"nominatim_result_json", "search_string", b"search_string"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GeolocationSearchInfoReq: typing_extensions.TypeAlias = GeolocationSearchInfoReq

@typing.final
class GeolocationClickInfoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTEXT_FIELD_NUMBER: builtins.int
    FORMATTED_RESULT_JSON_FIELD_NUMBER: builtins.int
    SEARCH_CHOICE_JSON_FIELD_NUMBER: builtins.int
    context: builtins.str
    formatted_result_json: builtins.str
    search_choice_json: builtins.str
    def __init__(
        self,
        *,
        context: builtins.str | None = ...,
        formatted_result_json: builtins.str | None = ...,
        search_choice_json: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["context", b"context", "formatted_result_json", b"formatted_result_json", "search_choice_json", b"search_choice_json"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GeolocationClickInfoReq: typing_extensions.TypeAlias = GeolocationClickInfoReq

@typing.final
class DiagnosticInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_FIELD_NUMBER: builtins.int
    PROPERTIES_JSON_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    OCCURRED_FIELD_NUMBER: builtins.int
    tag: builtins.str
    properties_json: builtins.str
    value: builtins.float
    @property
    def occurred(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        tag: builtins.str | None = ...,
        properties_json: builtins.str | None = ...,
        value: builtins.float | None = ...,
        occurred: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["occurred", b"occurred"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["occurred", b"occurred", "properties_json", b"properties_json", "tag", b"tag", "value", b"value"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DiagnosticInfo: typing_extensions.TypeAlias = DiagnosticInfo

@typing.final
class ReportDiagnosticsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FRONTEND_VERSION_FIELD_NUMBER: builtins.int
    INFOS_FIELD_NUMBER: builtins.int
    frontend_version: builtins.str
    @property
    def infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___DiagnosticInfo]: ...
    def __init__(
        self,
        *,
        frontend_version: builtins.str | None = ...,
        infos: collections.abc.Iterable[Global___DiagnosticInfo] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["frontend_version", b"frontend_version", "infos", b"infos"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ReportDiagnosticsReq: typing_extensions.TypeAlias = ReportDiagnosticsReq

@typing.final
class CheckNativeStatusReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEBUG_JSON_FIELD_NUMBER: builtins.int
    EAS_CLIENT_ID_FIELD_NUMBER: builtins.int
    INSTALL_ID_FIELD_NUMBER: builtins.int
    STICKY_ID_FIELD_NUMBER: builtins.int
    IDFV_FIELD_NUMBER: builtins.int
    ANDROID_ID_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    OS_VERSION_FIELD_NUMBER: builtins.int
    LOCALE_FIELD_NUMBER: builtins.int
    USER_STATE_FIELD_NUMBER: builtins.int
    APP_VARIANT_FIELD_NUMBER: builtins.int
    APP_VERSION_FIELD_NUMBER: builtins.int
    NATIVE_BUILD_FIELD_NUMBER: builtins.int
    EMBEDDED_DISPLAY_VERSION_FIELD_NUMBER: builtins.int
    EMBEDDED_DEBUG_VERSION_FIELD_NUMBER: builtins.int
    RUNNING_DISPLAY_VERSION_FIELD_NUMBER: builtins.int
    RUNNING_DEBUG_VERSION_FIELD_NUMBER: builtins.int
    RUNNING_DEBUG_VERSION_OTA_FIELD_NUMBER: builtins.int
    RUNTIME_VERSION_FIELD_NUMBER: builtins.int
    UPDATE_ID_FIELD_NUMBER: builtins.int
    IS_EMBEDDED_LAUNCH_FIELD_NUMBER: builtins.int
    LAUNCH_SOURCE_FIELD_NUMBER: builtins.int
    EMBEDDED_CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    PUSH_PERMISSION_FIELD_NUMBER: builtins.int
    PUSH_TOKEN_FIELD_NUMBER: builtins.int
    TIME_SINCE_LAST_OPEN_FIELD_NUMBER: builtins.int
    OCCURRED_FIELD_NUMBER: builtins.int
    debug_json: builtins.str
    eas_client_id: builtins.str
    """Device / install identity"""
    install_id: builtins.str
    sticky_id: builtins.str
    idfv: builtins.str
    android_id: builtins.str
    device_name: builtins.str
    platform: builtins.str
    os_version: builtins.str
    locale: builtins.str
    user_state: builtins.str
    app_variant: builtins.str
    """Build identity — the embedded store build, the running (possibly OTA) bundle,
    and the runtimeVersion/channel that decide which OTAs apply.
    """
    app_version: builtins.str
    native_build: builtins.str
    embedded_display_version: builtins.str
    embedded_debug_version: builtins.str
    running_display_version: builtins.str
    running_debug_version: builtins.str
    running_debug_version_ota: builtins.str
    runtime_version: builtins.str
    update_id: builtins.str
    is_embedded_launch: builtins.bool
    launch_source: builtins.str
    push_permission: builtins.str
    """Push + timing"""
    push_token: builtins.str
    @property
    def embedded_created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def time_since_last_open(self) -> google.protobuf.duration_pb2.Duration: ...
    @property
    def occurred(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        debug_json: builtins.str | None = ...,
        eas_client_id: builtins.str | None = ...,
        install_id: builtins.str | None = ...,
        sticky_id: builtins.str | None = ...,
        idfv: builtins.str | None = ...,
        android_id: builtins.str | None = ...,
        device_name: builtins.str | None = ...,
        platform: builtins.str | None = ...,
        os_version: builtins.str | None = ...,
        locale: builtins.str | None = ...,
        user_state: builtins.str | None = ...,
        app_variant: builtins.str | None = ...,
        app_version: builtins.str | None = ...,
        native_build: builtins.str | None = ...,
        embedded_display_version: builtins.str | None = ...,
        embedded_debug_version: builtins.str | None = ...,
        running_display_version: builtins.str | None = ...,
        running_debug_version: builtins.str | None = ...,
        running_debug_version_ota: builtins.str | None = ...,
        runtime_version: builtins.str | None = ...,
        update_id: builtins.str | None = ...,
        is_embedded_launch: builtins.bool | None = ...,
        launch_source: builtins.str | None = ...,
        embedded_created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        push_permission: builtins.str | None = ...,
        push_token: builtins.str | None = ...,
        time_since_last_open: google.protobuf.duration_pb2.Duration | None = ...,
        occurred: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["created_at", b"created_at", "embedded_created_at", b"embedded_created_at", "occurred", b"occurred", "time_since_last_open", b"time_since_last_open"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["android_id", b"android_id", "app_variant", b"app_variant", "app_version", b"app_version", "created_at", b"created_at", "debug_json", b"debug_json", "device_name", b"device_name", "eas_client_id", b"eas_client_id", "embedded_created_at", b"embedded_created_at", "embedded_debug_version", b"embedded_debug_version", "embedded_display_version", b"embedded_display_version", "idfv", b"idfv", "install_id", b"install_id", "is_embedded_launch", b"is_embedded_launch", "launch_source", b"launch_source", "locale", b"locale", "native_build", b"native_build", "occurred", b"occurred", "os_version", b"os_version", "platform", b"platform", "push_permission", b"push_permission", "push_token", b"push_token", "running_debug_version", b"running_debug_version", "running_debug_version_ota", b"running_debug_version_ota", "running_display_version", b"running_display_version", "runtime_version", b"runtime_version", "sticky_id", b"sticky_id", "time_since_last_open", b"time_since_last_open", "update_id", b"update_id", "user_state", b"user_state"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CheckNativeStatusReq: typing_extensions.TypeAlias = CheckNativeStatusReq

@typing.final
class NativeUpdateInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    REQUIRED_FIELD_NUMBER: builtins.int
    ACT_BY_FIELD_NUMBER: builtins.int
    NAG_INTERVAL_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    LINK_URL_FIELD_NUMBER: builtins.int
    LINK_TEXT_FIELD_NUMBER: builtins.int
    CAUSE_FIELD_NUMBER: builtins.int
    action: Global___NativeUpdateAction.ValueType
    required: builtins.bool
    """Advisory when false; when true the client must act by act_by (in the past = block now)."""
    message: builtins.str
    """Shown on the nag/block screen."""
    link_url: builtins.str
    """Where to send the user to update (store listing, or a different app for reinstall)."""
    link_text: builtins.str
    """Label for the link_url button (e.g. "Update now", "Get the new app")."""
    cause: Global___NativeUpdateCause.ValueType
    """Why the update is being asked for. The client uses this to pick the on-screen wording."""
    @property
    def act_by(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def nag_interval(self) -> google.protobuf.duration_pb2.Duration:
        """For advisory updates (required == false): after showing the nag, the client waits at least this
        long before showing it again. Ignored when required. Unset/zero = show once per app session.
        """

    def __init__(
        self,
        *,
        action: Global___NativeUpdateAction.ValueType | None = ...,
        required: builtins.bool | None = ...,
        act_by: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        nag_interval: google.protobuf.duration_pb2.Duration | None = ...,
        message: builtins.str | None = ...,
        link_url: builtins.str | None = ...,
        link_text: builtins.str | None = ...,
        cause: Global___NativeUpdateCause.ValueType | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["act_by", b"act_by", "nag_interval", b"nag_interval"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["act_by", b"act_by", "action", b"action", "cause", b"cause", "link_text", b"link_text", "link_url", b"link_url", "message", b"message", "nag_interval", b"nag_interval", "required", b"required"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___NativeUpdateInfo: typing_extensions.TypeAlias = NativeUpdateInfo

@typing.final
class CheckNativeStatusRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATE_INFO_FIELD_NUMBER: builtins.int
    @property
    def update_info(self) -> Global___NativeUpdateInfo: ...
    def __init__(
        self,
        *,
        update_info: Global___NativeUpdateInfo | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["update_info", b"update_info"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["update_info", b"update_info"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CheckNativeStatusRes: typing_extensions.TypeAlias = CheckNativeStatusRes

@typing.final
class EvaluateFeatureFlagReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLAG_KEY_FIELD_NUMBER: builtins.int
    flag_key: builtins.str
    def __init__(
        self,
        *,
        flag_key: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["flag_key", b"flag_key"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___EvaluateFeatureFlagReq: typing_extensions.TypeAlias = EvaluateFeatureFlagReq

@typing.final
class EvaluateFeatureFlagRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    @property
    def value(self) -> google.protobuf.struct_pb2.Value:
        """The flag's resolved value (bool, string, number, or JSON object/array). Unset when the flag
        isn't configured server-side, so the frontend's in-code default applies.
        """

    def __init__(
        self,
        *,
        value: google.protobuf.struct_pb2.Value | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["value", b"value"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["value", b"value"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___EvaluateFeatureFlagRes: typing_extensions.TypeAlias = EvaluateFeatureFlagRes

@typing.final
class LogExperimentExposureReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPERIMENT_KEY_FIELD_NUMBER: builtins.int
    EXPERIMENT_NAME_FIELD_NUMBER: builtins.int
    VARIATION_ID_FIELD_NUMBER: builtins.int
    VARIATION_KEY_FIELD_NUMBER: builtins.int
    VARIATION_NAME_FIELD_NUMBER: builtins.int
    HASH_ATTRIBUTE_FIELD_NUMBER: builtins.int
    HASH_VALUE_FIELD_NUMBER: builtins.int
    FEATURE_ID_FIELD_NUMBER: builtins.int
    IN_EXPERIMENT_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    HASH_USED_FIELD_NUMBER: builtins.int
    STICKY_BUCKET_USED_FIELD_NUMBER: builtins.int
    experiment_key: builtins.str
    experiment_name: builtins.str
    variation_id: builtins.int
    variation_key: builtins.str
    variation_name: builtins.str
    hash_attribute: builtins.str
    hash_value: builtins.str
    feature_id: builtins.str
    in_experiment: builtins.bool
    bucket: builtins.float
    hash_used: builtins.bool
    sticky_bucket_used: builtins.bool
    def __init__(
        self,
        *,
        experiment_key: builtins.str | None = ...,
        experiment_name: builtins.str | None = ...,
        variation_id: builtins.int | None = ...,
        variation_key: builtins.str | None = ...,
        variation_name: builtins.str | None = ...,
        hash_attribute: builtins.str | None = ...,
        hash_value: builtins.str | None = ...,
        feature_id: builtins.str | None = ...,
        in_experiment: builtins.bool | None = ...,
        bucket: builtins.float | None = ...,
        hash_used: builtins.bool | None = ...,
        sticky_bucket_used: builtins.bool | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["_bucket", b"_bucket", "_hash_used", b"_hash_used", "_sticky_bucket_used", b"_sticky_bucket_used", "bucket", b"bucket", "hash_used", b"hash_used", "sticky_bucket_used", b"sticky_bucket_used"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["_bucket", b"_bucket", "_hash_used", b"_hash_used", "_sticky_bucket_used", b"_sticky_bucket_used", "bucket", b"bucket", "experiment_key", b"experiment_key", "experiment_name", b"experiment_name", "feature_id", b"feature_id", "hash_attribute", b"hash_attribute", "hash_used", b"hash_used", "hash_value", b"hash_value", "in_experiment", b"in_experiment", "sticky_bucket_used", b"sticky_bucket_used", "variation_id", b"variation_id", "variation_key", b"variation_key", "variation_name", b"variation_name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__bucket: typing_extensions.TypeAlias = typing.Literal["bucket"]
    _WhichOneofArgType__bucket: typing_extensions.TypeAlias = typing.Literal["_bucket", b"_bucket"]
    _WhichOneofReturnType__hash_used: typing_extensions.TypeAlias = typing.Literal["hash_used"]
    _WhichOneofArgType__hash_used: typing_extensions.TypeAlias = typing.Literal["_hash_used", b"_hash_used"]
    _WhichOneofReturnType__sticky_bucket_used: typing_extensions.TypeAlias = typing.Literal["sticky_bucket_used"]
    _WhichOneofArgType__sticky_bucket_used: typing_extensions.TypeAlias = typing.Literal["_sticky_bucket_used", b"_sticky_bucket_used"]
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__bucket) -> _WhichOneofReturnType__bucket | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__hash_used) -> _WhichOneofReturnType__hash_used | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__sticky_bucket_used) -> _WhichOneofReturnType__sticky_bucket_used | None: ...

Global___LogExperimentExposureReq: typing_extensions.TypeAlias = LogExperimentExposureReq



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import dashboard_pb2
import grpc
import grpc.aio
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class DashboardStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetDashboardV2: grpc.UnaryUnaryMultiCallable[dashboard_pb2.GetDashboardV2Req, dashboard_pb2.GetDashboardV2Res]
    """Fetch all the content needed to render the dashboard in a single call, instead of fanning out
    to the individual RPCs. Each field mirrors the response of the RPC that previously populated it.
    """

class DashboardServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetDashboardV2(
        self,
        request: dashboard_pb2.GetDashboardV2Req,
        context: CouchersContext,
        session: orm.Session,
    ) -> dashboard_pb2.GetDashboardV2Res:
        """Fetch all the content needed to render the dashboard in a single call, instead of fanning out
        to the individual RPCs. Each field mirrors the response of the RPC that previously populated it.
        """

def add_DashboardServicer_to_server(servicer: DashboardServicer, server: grpc.Server) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import moderation_pb2 as moderation__pb2


class ModerationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetModerationQueue = channel.unary_unary(
                '/org.couchers.moderation.Moderation/GetModerationQueue',
                request_serializer=moderation__pb2.GetModerationQueueReq.SerializeToString,
                response_deserializer=moderation__pb2.GetModerationQueueRes.FromString,
                )
        self.GetModerationState = channel.unary_unary(
                '/org.couchers.moderation.Moderation/GetModerationState',
                request_serializer=moderation__pb2.GetModerationStateReq.SerializeToString,
                response_deserializer=moderation__pb2.GetModerationStateRes.FromString,
                )
        self.GetModerationLog = channel.unary_unary(
                '/org.couchers.moderation.Moderation/GetModerationLog',
                request_serializer=moderation__pb2.GetModerationLogReq.SerializeToString,
                response_deserializer=moderation__pb2.GetModerationLogRes.FromString,
                )
        self.ModerateContent = channel.unary_unary(
                '/org.couchers.moderation.Moderation/ModerateContent',
                request_serializer=moderation__pb2.ModerateContentReq.SerializeToString,
                response_deserializer=moderation__pb2.ModerateContentRes.FromString,
                )
        self.SetUserContentVisibility = channel.unary_unary(
                '/org.couchers.moderation.Moderation/SetUserContentVisibility',
                request_serializer=moderation__pb2.SetUserContentVisibilityReq.SerializeToString,
                response_deserializer=moderation__pb2.SetUserContentVisibilityRes.FromString,
                )
        self.ListModerationStates = channel.unary_unary(
                '/org.couchers.moderation.Moderation/ListModerationStates',
                request_serializer=moderation__pb2.ListModerationStatesReq.SerializeToString,
                response_deserializer=moderation__pb2.ListModerationStatesRes.FromString,
                )


class ModerationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetModerationQueue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModerationState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModerationLog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModerateContent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetUserContentVisibility(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModerationStates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModerationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetModerationQueue': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModerationQueue,
                    request_deserializer=moderation__pb2.GetModerationQueueReq.FromString,
                    response_serializer=moderation__pb2.GetModerationQueueRes.SerializeToString,
            ),
            'GetModerationState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModerationState,
                    request_deserializer=moderation__pb2.GetModerationStateReq.FromString,
                    response_serializer=moderation__pb2.GetModerationStateRes.SerializeToString,
            ),
            'GetModerationLog': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModerationLog,
                    request_deserializer=moderation__pb2.GetModerationLogReq.FromString,
                    response_serializer=moderation__pb2.GetModerationLogRes.SerializeToString,
            ),
            'ModerateContent': grpc.unary_unary_rpc_method_handler(
                    servicer.ModerateContent,
                    request_deserializer=moderation__pb2.ModerateContentReq.FromString,
                    response_serializer=moderation__pb2.ModerateContentRes.SerializeToString,
            ),
            'SetUserContentVisibility': grpc.unary_unary_rpc_method_handler(
                    servicer.SetUserContentVisibility,
                    request_deserializer=moderation__pb2.SetUserContentVisibilityReq.FromString,
                    response_serializer=moderation__pb2.SetUserContentVisibilityRes.SerializeToString,
            ),
            'ListModerationStates': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModerationStates,
                    request_deserializer=moderation__pb2.ListModerationStatesReq.FromString,
                    response_serializer=moderation__pb2.ListModerationStatesRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.moderation.Moderation', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Moderation(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetModerationQueue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.moderation.Moderation/GetModerationQueue',
            moderation__pb2.GetModerationQueueReq.SerializeToString,
            moderation__pb2.GetModerationQueueRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModerationState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.moderation.Moderation/GetModerationState',
            moderation__pb2.GetModerationStateReq.SerializeToString,
            moderation__pb2.GetModerationStateRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModerationLog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.moderation.Moderation/GetModerationLog',
            moderation__pb2.GetModerationLogReq.SerializeToString,
            moderation__pb2.GetModerationLogRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ModerateContent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.moderation.Moderation/ModerateContent',
            moderation__pb2.ModerateContentReq.SerializeToString,
            moderation__pb2.ModerateContentRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetUserContentVisibility(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.moderation.Moderation/SetUserContentVisibility',
            moderation__pb2.SetUserContentVisibilityReq.SerializeToString,
            moderation__pb2.SetUserContentVisibilityRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModerationStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.moderation.Moderation/ListModerationStates',
            moderation__pb2.ListModerationStatesReq.SerializeToString,
            moderation__pb2.ListModerationStatesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: communities.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import discussions_pb2 as discussions__pb2
from . import events_pb2 as events__pb2
from . import groups_pb2 as groups__pb2
from . import pages_pb2 as pages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63ommunities.proto\x12\x1corg.couchers.api.communities\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\x11\x64iscussions.proto\x1a\x0c\x65vents.proto\x1a\x0cgroups.proto\x1a\x0bpages.proto\"\xd8\x03\n\tCommunity\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x07parents\x18\x06 \x03(\x0b\x32\x1f.org.couchers.api.groups.Parent\x12/\n\tmain_page\x18\x07 \x01(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x0e\n\x06member\x18\x08 \x01(\x08\x12\r\n\x05\x61\x64min\x18\t \x01(\x08\x12\x14\n\x0cmember_count\x18\n \x01(\r\x12\x13\n\x0b\x61\x64min_count\x18\x0b \x01(\r\x12\x19\n\x11nearby_user_count\x18\x0c \x01(\r\x12\x14\n\x0c\x63\x61n_moderate\x18\r \x01(\x08\x12(\n small_community_features_enabled\x18\x0e \x01(\x08\x12\x39\n\tnode_type\x18\x10 \x01(\x0e\x32&.org.couchers.api.communities.NodeTypeJ\x04\x08\x0f\x10\x10R\x0e\x65vents_enabled\"\'\n\x0fGetCommunityReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\"Q\n\x12ListCommunitiesReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"k\n\x12ListCommunitiesRes\x12<\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32\'.org.couchers.api.communities.Community\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"P\n\x16ListUserCommunitiesReq\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"o\n\x16ListUserCommunitiesRes\x12<\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32\'.org.couchers.api.communities.Community\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\rListGroupsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"X\n\rListGroupsRes\x12.\n\x06groups\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.groups.Group\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\rListAdminsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"@\n\rListAdminsRes\x12\x16\n\x0e\x61\x64min_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x0b\x41\x64\x64\x41\x64minReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x14\n\x0c\x63ommunity_id\x18\x02 \x01(\x03\"7\n\x0eRemoveAdminReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x14\n\x0c\x63ommunity_id\x18\x02 \x01(\x03\"M\n\x0eListMembersReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"B\n\x0eListMembersRes\x12\x17\n\x0fmember_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x12ListNearbyUsersReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"F\n\x12ListNearbyUsersRes\x12\x17\n\x0fnearby_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\rListPlacesReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"V\n\rListPlacesRes\x12,\n\x06places\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\rListGuidesReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"V\n\rListGuidesRes\x12,\n\x06guides\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"s\n\rListEventsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04past\x18\x04 \x01(\x08\x12\x17\n\x0finclude_parents\x18\x05 \x01(\x08\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"X\n\rListEventsRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x12ListDiscussionsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"l\n\x12ListDiscussionsRes\x12=\n\x0b\x64iscussions\x18\x01 \x03(\x0b\x32(.org.couchers.api.discussions.Discussion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"(\n\x10JoinCommunityReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\")\n\x11LeaveCommunityReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\"8\n\x14SearchCommunitiesReq\x12\r\n\x05query\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\r\"T\n\x14SearchCommunitiesRes\x12<\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32\'.org.couchers.api.communities.Community\"\x84\x02\n\x10\x43ommunitySummary\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\x08\x12\x14\n\x0cmember_count\x18\x05 \x01(\r\x12\x30\n\x07parents\x18\x06 \x03(\x0b\x32\x1f.org.couchers.api.groups.Parent\x12+\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\tnode_type\x18\x08 \x01(\x0e\x32&.org.couchers.api.communities.NodeType\"\x17\n\x15ListAllCommunitiesReq\"\\\n\x15ListAllCommunitiesRes\x12\x43\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32..org.couchers.api.communities.CommunitySummary\"-\n\x18ListRecentCommunitiesReq\x12\x11\n\tpage_size\x18\x01 \x01(\r\"_\n\x18ListRecentCommunitiesRes\x12\x43\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32..org.couchers.api.communities.CommunitySummary*\xb7\x01\n\x08NodeType\x12\x19\n\x15NODE_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fNODE_TYPE_WORLD\x10\x01\x12\x19\n\x15NODE_TYPE_MACROREGION\x10\x02\x12\x14\n\x10NODE_TYPE_REGION\x10\x03\x12\x17\n\x13NODE_TYPE_SUBREGION\x10\x04\x12\x16\n\x12NODE_TYPE_LOCALITY\x10\x05\x12\x19\n\x15NODE_TYPE_SUBLOCALITY\x10\x06\x32\xdb\x0f\n\x0b\x43ommunities\x12h\n\x0cGetCommunity\x12-.org.couchers.api.communities.GetCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x12w\n\x0fListCommunities\x12\x30.org.couchers.api.communities.ListCommunitiesReq\x1a\x30.org.couchers.api.communities.ListCommunitiesRes\"\x00\x12h\n\nListGroups\x12+.org.couchers.api.communities.ListGroupsReq\x1a+.org.couchers.api.communities.ListGroupsRes\"\x00\x12h\n\nListAdmins\x12+.org.couchers.api.communities.ListAdminsReq\x1a+.org.couchers.api.communities.ListAdminsRes\"\x00\x12O\n\x08\x41\x64\x64\x41\x64min\x12).org.couchers.api.communities.AddAdminReq\x1a\x16.google.protobuf.Empty\"\x00\x12U\n\x0bRemoveAdmin\x12,.org.couchers.api.communities.RemoveAdminReq\x1a\x16.google.protobuf.Empty\"\x00\x12k\n\x0bListMembers\x12,.org.couchers.api.communities.ListMembersReq\x1a,.org.couchers.api.communities.ListMembersRes\"\x00\x12w\n\x0fListNearbyUsers\x12\x30.org.couchers.api.communities.ListNearbyUsersReq\x1a\x30.org.couchers.api.communities.ListNearbyUsersRes\"\x00\x12h\n\nListPlaces\x12+.org.couchers.api.communities.ListPlacesReq\x1a+.org.couchers.api.communities.ListPlacesRes\"\x00\x12h\n\nListGuides\x12+.org.couchers.api.communities.ListGuidesReq\x1a+.org.couchers.api.communities.ListGuidesRes\"\x00\x12h\n\nListEvents\x12+.org.couchers.api.communities.ListEventsReq\x1a+.org.couchers.api.communities.ListEventsRes\"\x00\x12w\n\x0fListDiscussions\x12\x30.org.couchers.api.communities.ListDiscussionsReq\x1a\x30.org.couchers.api.communities.ListDiscussionsRes\"\x00\x12Y\n\rJoinCommunity\x12..org.couchers.api.communities.JoinCommunityReq\x1a\x16.google.protobuf.Empty\"\x00\x12[\n\x0eLeaveCommunity\x12/.org.couchers.api.communities.LeaveCommunityReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x83\x01\n\x13ListUserCommunities\x12\x34.org.couchers.api.communities.ListUserCommunitiesReq\x1a\x34.org.couchers.api.communities.ListUserCommunitiesRes\"\x00\x12}\n\x11SearchCommunities\x12\x32.org.couchers.api.communities.SearchCommunitiesReq\x1a\x32.org.couchers.api.communities.SearchCommunitiesRes\"\x00\x12\x80\x01\n\x12ListAllCommunities\x12\x33.org.couchers.api.communities.ListAllCommunitiesReq\x1a\x33.org.couchers.api.communities.ListAllCommunitiesRes\"\x00\x12\x89\x01\n\x15ListRecentCommunities\x12\x36.org.couchers.api.communities.ListRecentCommunitiesReq\x1a\x36.org.couchers.api.communities.ListRecentCommunitiesRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'communities_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_COMMUNITIES']._loaded_options = None
  _globals['_COMMUNITIES']._serialized_options = b'\210\265\030\003'
  _globals['_NODETYPE']._serialized_start=3308
  _globals['_NODETYPE']._serialized_end=3491
  _globals['_COMMUNITY']._serialized_start=193
  _globals['_COMMUNITY']._serialized_end=665
  _globals['_GETCOMMUNITYREQ']._serialized_start=667
  _globals['_GETCOMMUNITYREQ']._serialized_end=706
  _globals['_LISTCOMMUNITIESREQ']._serialized_start=708
  _globals['_LISTCOMMUNITIESREQ']._serialized_end=789
  _globals['_LISTCOMMUNITIESRES']._serialized_start=791
  _globals['_LISTCOMMUNITIESRES']._serialized_end=898
  _globals['_LISTUSERCOMMUNITIESREQ']._serialized_start=900
  _globals['_LISTUSERCOMMUNITIESREQ']._serialized_end=980
  _globals['_LISTUSERCOMMUNITIESRES']._serialized_start=982
  _globals['_LISTUSERCOMMUNITIESRES']._serialized_end=1093
  _globals['_LISTGROUPSREQ']._serialized_start=1095
  _globals['_LISTGROUPSREQ']._serialized_end=1171
  _globals['_LISTGROUPSRES']._serialized_start=1173
  _globals['_LISTGROUPSRES']._serialized_end=1261
  _globals['_LISTADMINSREQ']._serialized_start=1263
  _globals['_LISTADMINSREQ']._serialized_end=1339
  _globals['_LISTADMINSRES']._serialized_start=1341
  _globals['_LISTADMINSRES']._serialized_end=1405
  _globals['_ADDADMINREQ']._serialized_start=1407
  _globals['_ADDADMINREQ']._serialized_end=1459
  _globals['_REMOVEADMINREQ']._serialized_start=1461
  _globals['_REMOVEADMINREQ']._serialized_end=1516
  _globals['_LISTMEMBERSREQ']._serialized_start=1518
  _globals['_LISTMEMBERSREQ']._serialized_end=1595
  _globals['_LISTMEMBERSRES']._serialized_start=1597
  _globals['_LISTMEMBERSRES']._serialized_end=1663
  _globals['_LISTNEARBYUSERSREQ']._serialized_start=1665
  _globals['_LISTNEARBYUSERSREQ']._serialized_end=1746
  _globals['_LISTNEARBYUSERSRES']._serialized_start=1748
  _globals['_LISTNEARBYUSERSRES']._serialized_end=1818
  _globals['_LISTPLACESREQ']._serialized_start=1820
  _globals['_LISTPLACESREQ']._serialized_end=1896
  _globals['_LISTPLACESRES']._serialized_start=1898
  _globals['_LISTPLACESRES']._serialized_end=1984
  _globals['_LISTGUIDESREQ']._serialized_start=1986
  _globals['_LISTGUIDESREQ']._serialized_end=2062
  _globals['_LISTGUIDESRES']._serialized_start=2064
  _globals['_LISTGUIDESRES']._serialized_end=2150
  _globals['_LISTEVENTSREQ']._serialized_start=2152
  _globals['_LISTEVENTSREQ']._serialized_end=2267
  _globals['_LISTEVENTSRES']._serialized_start=2269
  _globals['_LISTEVENTSRES']._serialized_end=2357
  _globals['_LISTDISCUSSIONSREQ']._serialized_start=2359
  _globals['_LISTDISCUSSIONSREQ']._serialized_end=2440
  _globals['_LISTDISCUSSIONSRES']._serialized_start=2442
  _globals['_LISTDISCUSSIONSRES']._serialized_end=2550
  _globals['_JOINCOMMUNITYREQ']._serialized_start=2552
  _globals['_JOINCOMMUNITYREQ']._serialized_end=2592
  _globals['_LEAVECOMMUNITYREQ']._serialized_start=2594
  _globals['_LEAVECOMMUNITYREQ']._serialized_end=2635
  _globals['_SEARCHCOMMUNITIESREQ']._serialized_start=2637
  _globals['_SEARCHCOMMUNITIESREQ']._serialized_end=2693
  _globals['_SEARCHCOMMUNITIESRES']._serialized_start=2695
  _globals['_SEARCHCOMMUNITIESRES']._serialized_end=2779
  _globals['_COMMUNITYSUMMARY']._serialized_start=2782
  _globals['_COMMUNITYSUMMARY']._serialized_end=3042
  _globals['_LISTALLCOMMUNITIESREQ']._serialized_start=3044
  _globals['_LISTALLCOMMUNITIESREQ']._serialized_end=3067
  _globals['_LISTALLCOMMUNITIESRES']._serialized_start=3069
  _globals['_LISTALLCOMMUNITIESRES']._serialized_end=3161
  _globals['_LISTRECENTCOMMUNITIESREQ']._serialized_start=3163
  _globals['_LISTRECENTCOMMUNITIESREQ']._serialized_end=3208
  _globals['_LISTRECENTCOMMUNITIESRES']._serialized_start=3210
  _globals['_LISTRECENTCOMMUNITIESRES']._serialized_end=3305
  _globals['_COMMUNITIES']._serialized_start=3494
  _globals['_COMMUNITIES']._serialized_end=5505
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import auth_pb2 as auth__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class AuthStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SignupFlow = channel.unary_unary(
                '/org.couchers.auth.Auth/SignupFlow',
                request_serializer=auth__pb2.SignupFlowReq.SerializeToString,
                response_deserializer=auth__pb2.SignupFlowRes.FromString,
                )
        self.UsernameValid = channel.unary_unary(
                '/org.couchers.auth.Auth/UsernameValid',
                request_serializer=auth__pb2.UsernameValidReq.SerializeToString,
                response_deserializer=auth__pb2.UsernameValidRes.FromString,
                )
        self.Authenticate = channel.unary_unary(
                '/org.couchers.auth.Auth/Authenticate',
                request_serializer=auth__pb2.AuthReq.SerializeToString,
                response_deserializer=auth__pb2.AuthRes.FromString,
                )
        self.GetAuthState = channel.unary_unary(
                '/org.couchers.auth.Auth/GetAuthState',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=auth__pb2.GetAuthStateRes.FromString,
                )
        self.Deauthenticate = channel.unary_unary(
                '/org.couchers.auth.Auth/Deauthenticate',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ResetPassword = channel.unary_unary(
                '/org.couchers.auth.Auth/ResetPassword',
                request_serializer=auth__pb2.ResetPasswordReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CompletePasswordResetV2 = channel.unary_unary(
                '/org.couchers.auth.Auth/CompletePasswordResetV2',
                request_serializer=auth__pb2.CompletePasswordResetV2Req.SerializeToString,
                response_deserializer=auth__pb2.AuthRes.FromString,
                )
        self.ConfirmChangeEmailV2 = channel.unary_unary(
                '/org.couchers.auth.Auth/ConfirmChangeEmailV2',
                request_serializer=auth__pb2.ConfirmChangeEmailV2Req.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ConfirmDeleteAccount = channel.unary_unary(
                '/org.couchers.auth.Auth/ConfirmDeleteAccount',
                request_serializer=auth__pb2.ConfirmDeleteAccountReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RecoverAccount = channel.unary_unary(
                '/org.couchers.auth.Auth/RecoverAccount',
                request_serializer=auth__pb2.RecoverAccountReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.Unsubscribe = channel.unary_unary(
                '/org.couchers.auth.Auth/Unsubscribe',
                request_serializer=auth__pb2.UnsubscribeReq.SerializeToString,
                response_deserializer=auth__pb2.UnsubscribeRes.FromString,
                )
        self.AntiBot = channel.unary_unary(
                '/org.couchers.auth.Auth/AntiBot',
                request_serializer=auth__pb2.AntiBotReq.SerializeToString,
                response_deserializer=auth__pb2.AntiBotRes.FromString,
                )
        self.AntiBotPolicy = channel.unary_unary(
                '/org.couchers.auth.Auth/AntiBotPolicy',
                request_serializer=auth__pb2.AntiBotPolicyReq.SerializeToString,
                response_deserializer=auth__pb2.AntiBotPolicyRes.FromString,
                )
        self.GetInviteCodeInfo = channel.unary_unary(
                '/org.couchers.auth.Auth/GetInviteCodeInfo',
                request_serializer=auth__pb2.GetInviteCodeInfoReq.SerializeToString,
                response_deserializer=auth__pb2.GetInviteCodeInfoRes.FromString,
                )


class AuthServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SignupFlow(self, request, context):
        """
        Authentication API

        This API facilitates authentication actions: signup and signin. Users need to use this before logging in, so you don't
        need to be authorized to use it.

        The signup flow is as follows:
        A user enters their email and submits a form, which fires off a Signup call
        Signup validates the email isn't in the database yet, creates a signup_token, and emails it to the email address
        User clicks on the signup link, which brings them onto the signup completion form
        When this form loads, the app queries SignupTokenInfo for the email address associated to that login token to
        display in the UI
        User chooses a username (possibly querying UsernameValid to check possibly usernames) and fills in other basic
        information
        User submits the signup completion form, which validates this input, creates the user and logs them in, returns a
        session token (signup token is invalidated)

        The login flow is as follows:
        User types in username and password and the frontend calls Authenticate

        Signup tokens expire after some time, and once used cannot be reused.

        There can be multiple signup requests simultaneously with the same email address. Email address uniqueness is checked
        once when creating the signup request, and again when creating the user.

        The signup flow (from point of view of backend) is as follows:
        * There are three parts to the signup: Basic, Account, and Feedback
        * Each part needs to be filled in, and the user's email needs to be confirmed before the user can continue to the
        app
        * The Basic part must be filled in in the first request, after which the backend returns a flow_token
        * The frontend may do the signup incrementally by sending the other parts with the same flow_token
        * You can only fill in each part once
        * You can get info on the flow_token by sending an empty request with just the flow_token
        * Once the flow completes, the user is logged in and the signup flow is destroyed
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UsernameValid(self, request, context):
        """Check whether the username is valid and available
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Authenticate(self, request, context):
        """Log in with username + password
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAuthState(self, request, context):
        """Get info on current authentication state
        we need this because the web client does not have access to the non-JS cookie that contains this info, so it
        needs to be validated against the backend
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deauthenticate(self, request, context):
        """Invalidate a session, deauthing a user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetPassword(self, request, context):
        """Sends a forgot password email to the given user if the user exists, returns no output (so you can't go around
        guessing email addresses)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompletePasswordResetV2(self, request, context):
        """Triggered when the user goes to the link sent in the forgot password email, and logs the user in

        Actually changes the user's password
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfirmChangeEmailV2(self, request, context):
        """Triggered when the user goes to the link sent in the either email_changed_confirmation_*_email
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfirmDeleteAccount(self, request, context):
        """Confirms deletion of a user using a token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecoverAccount(self, request, context):
        """Recovers a recently deleted account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Unsubscribe(self, request, context):
        """Handle an unsubscribe action from an email
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AntiBot(self, request, context):
        """Send antibot info asynchronously
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AntiBotPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInviteCodeInfo(self, request, context):
        """Returns basic profile of the invite code creator: name, username, avatar_url
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SignupFlow': grpc.unary_unary_rpc_method_handler(
                    servicer.SignupFlow,
                    request_deserializer=auth__pb2.SignupFlowReq.FromString,
                    response_serializer=auth__pb2.SignupFlowRes.SerializeToString,
            ),
            'UsernameValid': grpc.unary_unary_rpc_method_handler(
                    servicer.UsernameValid,
                    request_deserializer=auth__pb2.UsernameValidReq.FromString,
                    response_serializer=auth__pb2.UsernameValidRes.SerializeToString,
            ),
            'Authenticate': grpc.unary_unary_rpc_method_handler(
                    servicer.Authenticate,
                    request_deserializer=auth__pb2.AuthReq.FromString,
                    response_serializer=auth__pb2.AuthRes.SerializeToString,
            ),
            'GetAuthState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuthState,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=auth__pb2.GetAuthStateRes.SerializeToString,
            ),
            'Deauthenticate': grpc.unary_unary_rpc_method_handler(
                    servicer.Deauthenticate,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ResetPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetPassword,
                    request_deserializer=auth__pb2.ResetPasswordReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CompletePasswordResetV2': grpc.unary_unary_rpc_method_handler(
                    servicer.CompletePasswordResetV2,
                    request_deserializer=auth__pb2.CompletePasswordResetV2Req.FromString,
                    response_serializer=auth__pb2.AuthRes.SerializeToString,
            ),
            'ConfirmChangeEmailV2': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfirmChangeEmailV2,
                    request_deserializer=auth__pb2.ConfirmChangeEmailV2Req.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ConfirmDeleteAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfirmDeleteAccount,
                    request_deserializer=auth__pb2.ConfirmDeleteAccountReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RecoverAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.RecoverAccount,
                    request_deserializer=auth__pb2.RecoverAccountReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Unsubscribe': grpc.unary_unary_rpc_method_handler(
                    servicer.Unsubscribe,
                    request_deserializer=auth__pb2.UnsubscribeReq.FromString,
                    response_serializer=auth__pb2.UnsubscribeRes.SerializeToString,
            ),
            'AntiBot': grpc.unary_unary_rpc_method_handler(
                    servicer.AntiBot,
                    request_deserializer=auth__pb2.AntiBotReq.FromString,
                    response_serializer=auth__pb2.AntiBotRes.SerializeToString,
            ),
            'AntiBotPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.AntiBotPolicy,
                    request_deserializer=auth__pb2.AntiBotPolicyReq.FromString,
                    response_serializer=auth__pb2.AntiBotPolicyRes.SerializeToString,
            ),
            'GetInviteCodeInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInviteCodeInfo,
                    request_deserializer=auth__pb2.GetInviteCodeInfoReq.FromString,
                    response_serializer=auth__pb2.GetInviteCodeInfoRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.auth.Auth', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Auth(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SignupFlow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/SignupFlow',
            auth__pb2.SignupFlowReq.SerializeToString,
            auth__pb2.SignupFlowRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UsernameValid(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/UsernameValid',
            auth__pb2.UsernameValidReq.SerializeToString,
            auth__pb2.UsernameValidRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Authenticate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/Authenticate',
            auth__pb2.AuthReq.SerializeToString,
            auth__pb2.AuthRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAuthState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/GetAuthState',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            auth__pb2.GetAuthStateRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Deauthenticate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/Deauthenticate',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/ResetPassword',
            auth__pb2.ResetPasswordReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompletePasswordResetV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/CompletePasswordResetV2',
            auth__pb2.CompletePasswordResetV2Req.SerializeToString,
            auth__pb2.AuthRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfirmChangeEmailV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/ConfirmChangeEmailV2',
            auth__pb2.ConfirmChangeEmailV2Req.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfirmDeleteAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/ConfirmDeleteAccount',
            auth__pb2.ConfirmDeleteAccountReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecoverAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/RecoverAccount',
            auth__pb2.RecoverAccountReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Unsubscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/Unsubscribe',
            auth__pb2.UnsubscribeReq.SerializeToString,
            auth__pb2.UnsubscribeRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AntiBot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/AntiBot',
            auth__pb2.AntiBotReq.SerializeToString,
            auth__pb2.AntiBotRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AntiBotPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/AntiBotPolicy',
            auth__pb2.AntiBotPolicyReq.SerializeToString,
            auth__pb2.AntiBotPolicyRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInviteCodeInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/GetInviteCodeInfo',
            auth__pb2.GetInviteCodeInfoReq.SerializeToString,
            auth__pb2.GetInviteCodeInfoRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import jail_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class JailStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    JailInfo: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, jail_pb2.JailInfoRes]
    """
    Jail API

    If the user hasn't completed necessary steps needed to use the app, they are
    only allowed to hit the Jail API.

    E.g. if signing up is incomplete, or they haven't agreed to TOS, etc.

    These API functions are available only to signed-in users, but while other
    APIs can't be used while Jailed, these can.
    Get reason why the user is in jail, e.g. hasn't completed all sign-up
    steps, or needs to read something, etc
    """
    AcceptTOS: grpc.UnaryUnaryMultiCallable[jail_pb2.AcceptTOSReq, jail_pb2.JailInfoRes]
    """Accept TOS"""
    SetLocation: grpc.UnaryUnaryMultiCallable[jail_pb2.SetLocationReq, jail_pb2.JailInfoRes]
    """Set the user's location
    If you're not jailed, do this with api.UpdateProfile!
    """
    AcceptCommunityGuidelines: grpc.UnaryUnaryMultiCallable[jail_pb2.AcceptCommunityGuidelinesReq, jail_pb2.JailInfoRes]
    """Accept community guidelines"""
    AcknowledgePendingModNote: grpc.UnaryUnaryMultiCallable[jail_pb2.AcknowledgePendingModNoteReq, jail_pb2.JailInfoRes]
    """Acknowledges a mod note"""
    RespondToActivenessProbe: grpc.UnaryUnaryMultiCallable[jail_pb2.RespondToActivenessProbeReq, jail_pb2.JailInfoRes]
    """Either dismiss an activeness probe or say you aren't hosting"""

class JailServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def JailInfo(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> jail_pb2.JailInfoRes:
        """
        Jail API

        If the user hasn't completed necessary steps needed to use the app, they are
        only allowed to hit the Jail API.

        E.g. if signing up is incomplete, or they haven't agreed to TOS, etc.

        These API functions are available only to signed-in users, but while other
        APIs can't be used while Jailed, these can.
        Get reason why the user is in jail, e.g. hasn't completed all sign-up
        steps, or needs to read something, etc
        """

    @abc.abstractmethod
    def AcceptTOS(
        self,
        request: jail_pb2.AcceptTOSReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> jail_pb2.JailInfoRes:
        """Accept TOS"""

    @abc.abstractmethod
    def SetLocation(
        self,
        request: jail_pb2.SetLocationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> jail_pb2.JailInfoRes:
        """Set the user's location
        If you're not jailed, do this with api.UpdateProfile!
        """

    @abc.abstractmethod
    def AcceptCommunityGuidelines(
        self,
        request: jail_pb2.AcceptCommunityGuidelinesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> jail_pb2.JailInfoRes:
        """Accept community guidelines"""

    @abc.abstractmethod
    def AcknowledgePendingModNote(
        self,
        request: jail_pb2.AcknowledgePendingModNoteReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> jail_pb2.JailInfoRes:
        """Acknowledges a mod note"""

    @abc.abstractmethod
    def RespondToActivenessProbe(
        self,
        request: jail_pb2.RespondToActivenessProbeReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> jail_pb2.JailInfoRes:
        """Either dismiss an activeness probe or say you aren't hosting"""

def add_JailServicer_to_server(servicer: JailServicer, server: grpc.Server) -> None: ...



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import blocking_pb2
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class BlockingStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    BlockUser: grpc.UnaryUnaryMultiCallable[blocking_pb2.BlockUserReq, google.protobuf.empty_pb2.Empty]
    UnblockUser: grpc.UnaryUnaryMultiCallable[blocking_pb2.UnblockUserReq, google.protobuf.empty_pb2.Empty]
    GetBlockedUsers: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, blocking_pb2.GetBlockedUsersRes]
    """Returns all users blocked by a given account"""

class BlockingServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def BlockUser(
        self,
        request: blocking_pb2.BlockUserReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def UnblockUser(
        self,
        request: blocking_pb2.UnblockUserReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def GetBlockedUsers(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> blocking_pb2.GetBlockedUsersRes:
        """Returns all users blocked by a given account"""

def add_BlockingServicer_to_server(servicer: BlockingServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class InitiateDonationReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AMOUNT_FIELD_NUMBER: builtins.int
    RECURRING_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    amount: builtins.int
    """amount in USD, integral for now"""
    recurring: builtins.bool
    """whether to create a monthly recurring donation"""
    source: builtins.str
    """source of the donation (e.g., "strong-verification-complete")"""
    def __init__(
        self,
        *,
        amount: builtins.int | None = ...,
        recurring: builtins.bool | None = ...,
        source: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["amount", b"amount", "recurring", b"recurring", "source", b"source"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___InitiateDonationReq: typing_extensions.TypeAlias = InitiateDonationReq

@typing.final
class InitiateDonationRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STRIPE_CHECKOUT_SESSION_ID_FIELD_NUMBER: builtins.int
    STRIPE_CHECKOUT_URL_FIELD_NUMBER: builtins.int
    stripe_checkout_session_id: builtins.str
    stripe_checkout_url: builtins.str
    def __init__(
        self,
        *,
        stripe_checkout_session_id: builtins.str | None = ...,
        stripe_checkout_url: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["stripe_checkout_session_id", b"stripe_checkout_session_id", "stripe_checkout_url", b"stripe_checkout_url"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___InitiateDonationRes: typing_extensions.TypeAlias = InitiateDonationRes

@typing.final
class GetDonationPortalLinkRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STRIPE_PORTAL_URL_FIELD_NUMBER: builtins.int
    stripe_portal_url: builtins.str
    def __init__(
        self,
        *,
        stripe_portal_url: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["stripe_portal_url", b"stripe_portal_url"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetDonationPortalLinkRes: typing_extensions.TypeAlias = GetDonationPortalLinkRes



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import search_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class SearchStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Search: grpc.UnaryUnaryMultiCallable[search_pb2.SearchReq, search_pb2.SearchRes]
    """Search all content"""
    UserSearch: grpc.UnaryUnaryMultiCallable[search_pb2.UserSearchReq, search_pb2.UserSearchRes]
    """Search for users in particular with extra filters, e.g. hosts"""
    UserSearchV2: grpc.UnaryUnaryMultiCallable[search_pb2.UserSearchReq, search_pb2.UserSearchV2Res]
    """Search for users in particular with extra filters, e.g. hosts
    only returns used fields
    """
    EventSearch: grpc.UnaryUnaryMultiCallable[search_pb2.EventSearchReq, search_pb2.EventSearchRes]
    """Search for events in particular with extra filters"""

class SearchServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Search(
        self,
        request: search_pb2.SearchReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> search_pb2.SearchRes:
        """Search all content"""

    @abc.abstractmethod
    def UserSearch(
        self,
        request: search_pb2.UserSearchReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> search_pb2.UserSearchRes:
        """Search for users in particular with extra filters, e.g. hosts"""

    @abc.abstractmethod
    def UserSearchV2(
        self,
        request: search_pb2.UserSearchReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> search_pb2.UserSearchV2Res:
        """Search for users in particular with extra filters, e.g. hosts
        only returns used fields
        """

    @abc.abstractmethod
    def EventSearch(
        self,
        request: search_pb2.EventSearchReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> search_pb2.EventSearchRes:
        """Search for events in particular with extra filters"""

def add_SearchServicer_to_server(servicer: SearchServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: public.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cpublic.proto\x12\x13org.couchers.public\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/httpbody.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\" \n\x10GetPublicUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x9b\x02\n\x0bLimitedUser\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ity\x18\x03 \x01(\t\x12\x10\n\x08hometown\x18\x04 \x01(\t\x12\x16\n\x0enum_references\x18\x05 \x01(\r\x12*\n\x06joined\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x0ehosting_status\x18\x07 \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12:\n\rmeetup_status\x18\x08 \x01(\x0e\x32#.org.couchers.api.core.MeetupStatus\x12\x0e\n\x06\x62\x61\x64ges\x18\t \x03(\t\"\x80\x05\n\x08MostUser\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ity\x18\x03 \x01(\t\x12\x10\n\x08hometown\x18\x04 \x01(\t\x12\x10\n\x08timezone\x18\x05 \x01(\t\x12\x16\n\x0enum_references\x18\x06 \x01(\r\x12\x0e\n\x06gender\x18\x07 \x01(\t\x12\x10\n\x08pronouns\x18\x08 \x01(\t\x12\x0b\n\x03\x61ge\x18\t \x01(\r\x12*\n\x06joined\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0blast_active\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x0ehosting_status\x18\x0c \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12:\n\rmeetup_status\x18\r \x01(\x0e\x32#.org.couchers.api.core.MeetupStatus\x12\x12\n\noccupation\x18\x0e \x01(\t\x12\x11\n\teducation\x18\x0f \x01(\t\x12\x10\n\x08\x61\x62out_me\x18\x10 \x01(\t\x12\x15\n\rthings_i_like\x18\x11 \x01(\t\x12\x17\n\x0fregions_visited\x18\x12 \x03(\t\x12\x15\n\rregions_lived\x18\x13 \x03(\t\x12\x12\n\navatar_url\x18\x14 \x01(\t\x12\x1c\n\x14\x61vatar_thumbnail_url\x18\x15 \x01(\t\x12\x42\n\x12language_abilities\x18\x16 \x03(\x0b\x32&.org.couchers.api.core.LanguageAbility\x12\x0e\n\x06\x62\x61\x64ges\x18\x17 \x03(\t\"\xbd\x01\n\x10GetPublicUserRes\x12\x38\n\x0climited_user\x18\x01 \x01(\x0b\x32 .org.couchers.public.LimitedUserH\x00\x12\x32\n\tmost_user\x18\x02 \x01(\x0b\x32\x1d.org.couchers.public.MostUserH\x00\x12\x30\n\tfull_user\x18\x03 \x01(\x0b\x32\x1b.org.couchers.api.core.UserH\x00\x42\t\n\x07profile\"r\n\x14GetSignupPageInfoRes\x12/\n\x0blast_signup\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rlast_location\x18\x02 \x01(\t\x12\x12\n\nuser_count\x18\x03 \x01(\x04\"\xa9\x01\n\tVolunteer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x17\n\x0fis_board_member\x18\x03 \x01(\x08\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0b\n\x03img\x18\x06 \x01(\t\x12\x11\n\tlink_type\x18\x07 \x01(\t\x12\x11\n\tlink_text\x18\x08 \x01(\t\x12\x10\n\x08link_url\x18\t \x01(\t\"\x87\x01\n\x10GetVolunteersRes\x12:\n\x12\x63urrent_volunteers\x18\x01 \x03(\x0b\x32\x1e.org.couchers.public.Volunteer\x12\x37\n\x0fpast_volunteers\x18\x02 \x03(\x0b\x32\x1e.org.couchers.public.Volunteer\">\n\x13GetDonationStatsRes\x12\x19\n\x11total_donated_ytd\x18\x01 \x01(\x04\x12\x0c\n\x04goal\x18\x02 \x01(\x04\x32\xae\x04\n\x06Public\x12]\n\x0eGetPublicUsers\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/geojson/public-users\x12_\n\rGetPublicUser\x12%.org.couchers.public.GetPublicUserReq\x1a%.org.couchers.public.GetPublicUserRes\"\x00\x12x\n\x11GetSignupPageInfo\x12\x16.google.protobuf.Empty\x1a).org.couchers.public.GetSignupPageInfoRes\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/public/signup-page-info\x12n\n\rGetVolunteers\x12\x16.google.protobuf.Empty\x1a%.org.couchers.public.GetVolunteersRes\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/public/volunteer-info\x12t\n\x10GetDonationStats\x12\x16.google.protobuf.Empty\x1a(.org.couchers.public.GetDonationStatsRes\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/public/donation-stats\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'public_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PUBLIC']._loaded_options = None
  _globals['_PUBLIC']._serialized_options = b'\210\265\030\001'
  _globals['_PUBLIC'].methods_by_name['GetPublicUsers']._loaded_options = None
  _globals['_PUBLIC'].methods_by_name['GetPublicUsers']._serialized_options = b'\202\323\344\223\002\027\022\025/geojson/public-users'
  _globals['_PUBLIC'].methods_by_name['GetSignupPageInfo']._loaded_options = None
  _globals['_PUBLIC'].methods_by_name['GetSignupPageInfo']._serialized_options = b'\202\323\344\223\002\032\022\030/public/signup-page-info'
  _globals['_PUBLIC'].methods_by_name['GetVolunteers']._loaded_options = None
  _globals['_PUBLIC'].methods_by_name['GetVolunteers']._serialized_options = b'\202\323\344\223\002\030\022\026/public/volunteer-info'
  _globals['_PUBLIC'].methods_by_name['GetDonationStats']._loaded_options = None
  _globals['_PUBLIC'].methods_by_name['GetDonationStats']._serialized_options = b'\202\323\344\223\002\030\022\026/public/donation-stats'
  _globals['_GETPUBLICUSERREQ']._serialized_start=186
  _globals['_GETPUBLICUSERREQ']._serialized_end=218
  _globals['_LIMITEDUSER']._serialized_start=221
  _globals['_LIMITEDUSER']._serialized_end=504
  _globals['_MOSTUSER']._serialized_start=507
  _globals['_MOSTUSER']._serialized_end=1147
  _globals['_GETPUBLICUSERRES']._serialized_start=1150
  _globals['_GETPUBLICUSERRES']._serialized_end=1339
  _globals['_GETSIGNUPPAGEINFORES']._serialized_start=1341
  _globals['_GETSIGNUPPAGEINFORES']._serialized_end=1455
  _globals['_VOLUNTEER']._serialized_start=1458
  _globals['_VOLUNTEER']._serialized_end=1627
  _globals['_GETVOLUNTEERSRES']._serialized_start=1630
  _globals['_GETVOLUNTEERSRES']._serialized_end=1765
  _globals['_GETDONATIONSTATSRES']._serialized_start=1767
  _globals['_GETDONATIONSTATSRES']._serialized_end=1829
  _globals['_PUBLIC']._serialized_start=1832
  _globals['_PUBLIC']._serialized_end=2390
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import api_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetPublicUserReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    user: builtins.str
    """username only"""
    def __init__(
        self,
        *,
        user: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["user", b"user"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetPublicUserReq: typing_extensions.TypeAlias = GetPublicUserReq

@typing.final
class LimitedUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CITY_FIELD_NUMBER: builtins.int
    HOMETOWN_FIELD_NUMBER: builtins.int
    NUM_REFERENCES_FIELD_NUMBER: builtins.int
    JOINED_FIELD_NUMBER: builtins.int
    HOSTING_STATUS_FIELD_NUMBER: builtins.int
    MEETUP_STATUS_FIELD_NUMBER: builtins.int
    BADGES_FIELD_NUMBER: builtins.int
    username: builtins.str
    name: builtins.str
    city: builtins.str
    hometown: builtins.str
    num_references: builtins.int
    hosting_status: api_pb2.HostingStatus.ValueType
    meetup_status: api_pb2.MeetupStatus.ValueType
    @property
    def joined(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """not exact"""

    @property
    def badges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        username: builtins.str | None = ...,
        name: builtins.str | None = ...,
        city: builtins.str | None = ...,
        hometown: builtins.str | None = ...,
        num_references: builtins.int | None = ...,
        joined: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        hosting_status: api_pb2.HostingStatus.ValueType | None = ...,
        meetup_status: api_pb2.MeetupStatus.ValueType | None = ...,
        badges: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["joined", b"joined"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["badges", b"badges", "city", b"city", "hometown", b"hometown", "hosting_status", b"hosting_status", "joined", b"joined", "meetup_status", b"meetup_status", "name", b"name", "num_references", b"num_references", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___LimitedUser: typing_extensions.TypeAlias = LimitedUser

@typing.final
class MostUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CITY_FIELD_NUMBER: builtins.int
    HOMETOWN_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    NUM_REFERENCES_FIELD_NUMBER: builtins.int
    GENDER_FIELD_NUMBER: builtins.int
    PRONOUNS_FIELD_NUMBER: builtins.int
    AGE_FIELD_NUMBER: builtins.int
    JOINED_FIELD_NUMBER: builtins.int
    LAST_ACTIVE_FIELD_NUMBER: builtins.int
    HOSTING_STATUS_FIELD_NUMBER: builtins.int
    MEETUP_STATUS_FIELD_NUMBER: builtins.int
    OCCUPATION_FIELD_NUMBER: builtins.int
    EDUCATION_FIELD_NUMBER: builtins.int
    ABOUT_ME_FIELD_NUMBER: builtins.int
    THINGS_I_LIKE_FIELD_NUMBER: builtins.int
    REGIONS_VISITED_FIELD_NUMBER: builtins.int
    REGIONS_LIVED_FIELD_NUMBER: builtins.int
    AVATAR_URL_FIELD_NUMBER: builtins.int
    AVATAR_THUMBNAIL_URL_FIELD_NUMBER: builtins.int
    LANGUAGE_ABILITIES_FIELD_NUMBER: builtins.int
    BADGES_FIELD_NUMBER: builtins.int
    username: builtins.str
    name: builtins.str
    city: builtins.str
    hometown: builtins.str
    timezone: builtins.str
    num_references: builtins.int
    gender: builtins.str
    pronouns: builtins.str
    age: builtins.int
    hosting_status: api_pb2.HostingStatus.ValueType
    meetup_status: api_pb2.MeetupStatus.ValueType
    occupation: builtins.str
    education: builtins.str
    """CommonMark without images"""
    about_me: builtins.str
    """CommonMark without images"""
    things_i_like: builtins.str
    """CommonMark without images"""
    avatar_url: builtins.str
    avatar_thumbnail_url: builtins.str
    @property
    def joined(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """not exact"""

    @property
    def last_active(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """not exact"""

    @property
    def regions_visited(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def regions_lived(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def language_abilities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[api_pb2.LanguageAbility]: ...
    @property
    def badges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        username: builtins.str | None = ...,
        name: builtins.str | None = ...,
        city: builtins.str | None = ...,
        hometown: builtins.str | None = ...,
        timezone: builtins.str | None = ...,
        num_references: builtins.int | None = ...,
        gender: builtins.str | None = ...,
        pronouns: builtins.str | None = ...,
        age: builtins.int | None = ...,
        joined: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_active: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        hosting_status: api_pb2.HostingStatus.ValueType | None = ...,
        meetup_status: api_pb2.MeetupStatus.ValueType | None = ...,
        occupation: builtins.str | None = ...,
        education: builtins.str | None = ...,
        about_me: builtins.str | None = ...,
        things_i_like: builtins.str | None = ...,
        regions_visited: collections.abc.Iterable[builtins.str] | None = ...,
        regions_lived: collections.abc.Iterable[builtins.str] | None = ...,
        avatar_url: builtins.str | None = ...,
        avatar_thumbnail_url: builtins.str | None = ...,
        language_abilities: collections.abc.Iterable[api_pb2.LanguageAbility] | None = ...,
        badges: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["joined", b"joined", "last_active", b"last_active"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["about_me", b"about_me", "age", b"age", "avatar_thumbnail_url", b"avatar_thumbnail_url", "avatar_url", b"avatar_url", "badges", b"badges", "city", b"city", "education", b"education", "gender", b"gender", "hometown", b"hometown", "hosting_status", b"hosting_status", "joined", b"joined", "language_abilities", b"language_abilities", "last_active", b"last_active", "meetup_status", b"meetup_status", "name", b"name", "num_references", b"num_references", "occupation", b"occupation", "pronouns", b"pronouns", "regions_lived", b"regions_lived", "regions_visited", b"regions_visited", "things_i_like", b"things_i_like", "timezone", b"timezone", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MostUser: typing_extensions.TypeAlias = MostUser

@typing.final
class GetPublicUserRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIMITED_USER_FIELD_NUMBER: builtins.int
    MOST_USER_FIELD_NUMBER: builtins.int
    FULL_USER_FIELD_NUMBER: builtins.int
    @property
    def limited_user(self) -> Global___LimitedUser: ...
    @property
    def most_user(self) -> Global___MostUser: ...
    @property
    def full_user(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        limited_user: Global___LimitedUser | None = ...,
        most_user: Global___MostUser | None = ...,
        full_user: api_pb2.User | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["full_user", b"full_user", "limited_user", b"limited_user", "most_user", b"most_user", "profile", b"profile"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["full_user", b"full_user", "limited_user", b"limited_user", "most_user", b"most_user", "profile", b"profile"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_profile: typing_extensions.TypeAlias = typing.Literal["limited_user", "most_user", "full_user"]
    _WhichOneofArgType_profile: typing_extensions.TypeAlias = typing.Literal["profile", b"profile"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType_profile) -> _WhichOneofReturnType_profile | None: ...

Global___GetPublicUserRes: typing_extensions.TypeAlias = GetPublicUserRes

@typing.final
class GetSignupPageInfoRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_SIGNUP_FIELD_NUMBER: builtins.int
    LAST_LOCATION_FIELD_NUMBER: builtins.int
    USER_COUNT_FIELD_NUMBER: builtins.int
    last_location: builtins.str
    user_count: builtins.int
    @property
    def last_signup(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        last_signup: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_location: builtins.str | None = ...,
        user_count: builtins.int | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["last_signup", b"last_signup"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["last_location", b"last_location", "last_signup", b"last_signup", "user_count", b"user_count"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetSignupPageInfoRes: typing_extensions.TypeAlias = GetSignupPageInfoRes

@typing.final
class Volunteer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    IS_BOARD_MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    IMG_FIELD_NUMBER: builtins.int
    LINK_TYPE_FIELD_NUMBER: builtins.int
    LINK_TEXT_FIELD_NUMBER: builtins.int
    LINK_URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    """display name"""
    username: builtins.str
    """couchers username"""
    is_board_member: builtins.bool
    """whether the user is a board member (and director)"""
    role: builtins.str
    """volunteer defined role"""
    location: builtins.str
    """location from profile"""
    img: builtins.str
    """avatar from profile"""
    link_type: builtins.str
    """link type, one of couchers, email, linkedin, website"""
    link_text: builtins.str
    """the text to be shown on the link"""
    link_url: builtins.str
    """the URL the link should take you to"""
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        username: builtins.str | None = ...,
        is_board_member: builtins.bool | None = ...,
        role: builtins.str | None = ...,
        location: builtins.str | None = ...,
        img: builtins.str | None = ...,
        link_type: builtins.str | None = ...,
        link_text: builtins.str | None = ...,
        link_url: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["img", b"img", "is_board_member", b"is_board_member", "link_text", b"link_text", "link_type", b"link_type", "link_url", b"link_url", "location", b"location", "name", b"name", "role", b"role", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Volunteer: typing_extensions.TypeAlias = Volunteer

@typing.final
class GetVolunteersRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENT_VOLUNTEERS_FIELD_NUMBER: builtins.int
    PAST_VOLUNTEERS_FIELD_NUMBER: builtins.int
    @property
    def current_volunteers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Volunteer]: ...
    @property
    def past_volunteers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Volunteer]: ...
    def __init__(
        self,
        *,
        current_volunteers: collections.abc.Iterable[Global___Volunteer] | None = ...,
        past_volunteers: collections.abc.Iterable[Global___Volunteer] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["current_volunteers", b"current_volunteers", "past_volunteers", b"past_volunteers"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetVolunteersRes: typing_extensions.TypeAlias = GetVolunteersRes

@typing.final
class GetDonationStatsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_DONATED_YTD_FIELD_NUMBER: builtins.int
    GOAL_FIELD_NUMBER: builtins.int
    total_donated_ytd: builtins.int
    """Total donations received this year in USD (whole dollars)"""
    goal: builtins.int
    """The fundraising goal in USD (whole dollars)"""
    def __init__(
        self,
        *,
        total_donated_ytd: builtins.int | None = ...,
        goal: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["goal", b"goal", "total_donated_ytd", b"total_donated_ytd"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetDonationStatsRes: typing_extensions.TypeAlias = GetDonationStatsRes



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import notifications_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class NotificationsStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetNotificationSettings: grpc.UnaryUnaryMultiCallable[notifications_pb2.GetNotificationSettingsReq, notifications_pb2.GetNotificationSettingsRes]
    SetNotificationSettings: grpc.UnaryUnaryMultiCallable[notifications_pb2.SetNotificationSettingsReq, notifications_pb2.GetNotificationSettingsRes]
    ListNotifications: grpc.UnaryUnaryMultiCallable[notifications_pb2.ListNotificationsReq, notifications_pb2.ListNotificationsRes]
    MarkNotificationSeen: grpc.UnaryUnaryMultiCallable[notifications_pb2.MarkNotificationSeenReq, google.protobuf.empty_pb2.Empty]
    MarkAllNotificationsSeen: grpc.UnaryUnaryMultiCallable[notifications_pb2.MarkAllNotificationsSeenReq, google.protobuf.empty_pb2.Empty]
    GetVapidPublicKey: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, notifications_pb2.GetVapidPublicKeyRes]
    RegisterPushNotificationSubscription: grpc.UnaryUnaryMultiCallable[notifications_pb2.RegisterPushNotificationSubscriptionReq, google.protobuf.empty_pb2.Empty]
    SendTestPushNotification: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, google.protobuf.empty_pb2.Empty]
    RegisterMobilePushNotificationSubscription: grpc.UnaryUnaryMultiCallable[notifications_pb2.RegisterMobilePushNotificationSubscriptionReq, google.protobuf.empty_pb2.Empty]
    SendTestMobilePushNotification: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, google.protobuf.empty_pb2.Empty]
    SendDevPushNotification: grpc.UnaryUnaryMultiCallable[notifications_pb2.SendDevPushNotificationReq, google.protobuf.empty_pb2.Empty]
    """Development API: Send an arbitrary push notification to the current user.
    Gated behind ENABLE_DEV_APIS config.
    """
    DebugRedeliverPushNotification: grpc.UnaryUnaryMultiCallable[notifications_pb2.DebugRedeliverPushNotificationReq, google.protobuf.empty_pb2.Empty]
    """Debug API: Redeliver a push notification by notification_id.
    Gated behind ENABLE_DEV_APIS config.
    """

class NotificationsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetNotificationSettings(
        self,
        request: notifications_pb2.GetNotificationSettingsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> notifications_pb2.GetNotificationSettingsRes: ...

    @abc.abstractmethod
    def SetNotificationSettings(
        self,
        request: notifications_pb2.SetNotificationSettingsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> notifications_pb2.GetNotificationSettingsRes: ...

    @abc.abstractmethod
    def ListNotifications(
        self,
        request: notifications_pb2.ListNotificationsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> notifications_pb2.ListNotificationsRes: ...

    @abc.abstractmethod
    def MarkNotificationSeen(
        self,
        request: notifications_pb2.MarkNotificationSeenReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def MarkAllNotificationsSeen(
        self,
        request: notifications_pb2.MarkAllNotificationsSeenReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def GetVapidPublicKey(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> notifications_pb2.GetVapidPublicKeyRes: ...

    @abc.abstractmethod
    def RegisterPushNotificationSubscription(
        self,
        request: notifications_pb2.RegisterPushNotificationSubscriptionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def SendTestPushNotification(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def RegisterMobilePushNotificationSubscription(
        self,
        request: notifications_pb2.RegisterMobilePushNotificationSubscriptionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def SendTestMobilePushNotification(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def SendDevPushNotification(
        self,
        request: notifications_pb2.SendDevPushNotificationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Development API: Send an arbitrary push notification to the current user.
        Gated behind ENABLE_DEV_APIS config.
        """

    @abc.abstractmethod
    def DebugRedeliverPushNotification(
        self,
        request: notifications_pb2.DebugRedeliverPushNotificationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Debug API: Redeliver a push notification by notification_id.
        Gated behind ENABLE_DEV_APIS config.
        """

def add_NotificationsServicer_to_server(servicer: NotificationsServicer, server: grpc.Server) -> None: ...
